@@ -11,15 +11,20 @@ Adds author information.
 
 =cut
 
-# XXX: todo; real users :)
 sub filter {
     return
       sub {
           my $self = shift;
           my $context = shift;
           my $item = shift;
-          $item->metadata->{raw_author} = $item->metadata->{author};
-          $item->metadata->{author} = Angerwhale::User::Anonymous->new;
+
+          my $id = $item->metadata->{raw_author} = $item->metadata->{author};
+          my $author = eval {
+              $context->model('UserStore')->get_user_by_nice_id($id)
+                if $id;
+          };
+          $author ||= Angerwhale::User::Anonymous->new;
+          $item->metadata->{author} = $author;
           return $item;
       };
 }
