@@ -9,10 +9,10 @@ use YAML::Syck;
 sub process {
     my ( $self, $c ) = @_;
     my @items = $self->prepare_items($c);
-
+    
     # all went well, so we're done
     $c->response->content_type('text/x-yaml; charset=utf-8');
-    $c->response->body( Dump(@items) );
+    $c->response->body( Dump(@items) || '---\n' );
 }
 
 1;
